OC.L10N.register(
    "core",
    {
    "Please select a file." : "Valitse tiedosto.",
    "File is too big" : "Tiedosto on liian suuri",
    "The selected file is not an image." : "Valittu tiedosto ei ole kuva.",
    "The selected file cannot be read." : "Valittua tiedostoa ei voi lukea.",
    "The file was uploaded" : "Tiedosto lähetettiin",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Ladattu tiedosto on suurempi kuin php.ini-tiedostossa määritelty upload_max_filesize",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Ladattu tiedosto on suurempi kuin HTML-lomakkeessa määritelty MAX_FILE_SIZE",
    "The file was only partially uploaded" : "Tiedosto lähetettiin vain osittain",
    "No file was uploaded" : "Tiedostoja ei lähetetty",
    "Missing a temporary folder" : "Väliaikaiskansio puuttuu",
    "Could not write file to disk" : "Ei voitu kirjoittaa levylle",
    "A PHP extension stopped the file upload" : "PHP-laajennus pysäytti tiedoston lähetyksen",
    "Invalid file provided" : "Määritetty virheellinen tiedosto",
    "No image or file provided" : "Kuvaa tai tiedostoa ei määritelty",
    "Unknown filetype" : "Tuntematon tiedostotyyppi",
    "An error occurred. Please contact your admin." : "Tapahtui virhe. Ota yhteys ylläpitoon.",
    "Invalid image" : "Virheellinen kuva",
    "No temporary profile picture available, try again" : "Väliaikaista profiilikuvaa ei ole käytettävissä, yritä uudelleen",
    "No crop data provided" : "Leikkaustietoa ei annettu",
    "No valid crop data provided" : "Kelvollisia leikkaustietoja ei määritetty",
    "Crop is not square" : "Leikkaus ei ole neliö",
    "State token does not match" : "Tilapoletti ei täsmää",
    "Invalid app password" : "Virheellinen sovellussalasana",
    "Could not complete login" : "Kirjautumista ei voitu suorittaa loppuun",
    "Your login token is invalid or has expired" : "Kirjautumispolettisi on virheellinen tai se on vanhentunut",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Tämä Nextcloudin yhteisöjulkaisu ei ole tuettu ja push-ilmoituksia on rajoitettu.",
    "Login" : "Kirjaudu sisään",
    "Password reset is disabled" : "Salasanan palautus poistettu käytöstä",
    "Could not reset password because the token is expired" : "Salasanaa ei voitu nollata, koska poletti on vanhentunut",
    "Could not reset password because the token is invalid" : "Salasanaa ei voitu nollata, koska poletti on virheellinen",
    "%s password reset" : "%s salasanan palautus",
    "Password reset" : "Salasanan palautus",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Paina oheista painiketta palauttaaksesi salasanasi. Jos et ole pyytänyt salasanan palautusta, jätä tämä sähköpostiviesti huomioimatta.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Paina oheista linkkiä palauttaaksesi salasanasi. Jos et ole pyytänyt salasanan palautusta, jätä tämä sähköpostiviesti huomioimatta.",
    "Reset your password" : "Palauta salasanasi",
    "Nextcloud Server" : "Nextcloud-palvelin",
    "Some of your link shares have been removed" : "Jotkin linkkijakosi on poistettu",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Tietoturvaongelman vuoksi jouduimme poistaa joitakin linkkijakojasi. Lue lisätietoja linkin kautta.",
    "The user limit of this instance is reached." : "Tämän instanssin käyttäjäraja on täynnä.",
    "Learn more ↗" : "Lue lisää ↗",
    "Preparing update" : "Valmistellaan päivitystä",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Korjausvaihe:",
    "Repair info:" : "Korjaustiedot:",
    "Repair warning:" : "Korjausvaroitus:",
    "Repair error:" : "Korjausvirhe:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Käytä komentorivipäivitintä, koska automaattinen päivitys on estetty config.php-asetustiedostossa.",
    "Turned on maintenance mode" : "Siirrytty huoltotilaan",
    "Turned off maintenance mode" : "Poistuttu huoltotilasta",
    "Maintenance mode is kept active" : "Huoltotila pidetään aktiivisena",
    "Updating database schema" : "Päivitetään tietokannan skeemaa",
    "Updated database" : "Tietokanta päivitetty",
    "Update app \"%s\" from App Store" : "Päivitä sovellus \"%s\" sovelluskaupasta",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Tarkistetaan, onko kohteen %s tietokannan skeemaa mahdollista päivittää (tämä saattaa kestää kauan riippuen tietokannan koosta)",
    "Updated \"%1$s\" to %2$s" : "Päivitetty \"%1$s\" versioon %2$s",
    "Set log level to debug" : "Asetettu lokitasoksi vianetsintä",
    "Reset log level" : "Nollattu lokitaso",
    "Starting code integrity check" : "Aloitetaan koodin eheystarkistus",
    "Finished code integrity check" : "Koodin eheystarkistus suoritettu",
    "%s (incompatible)" : "%s (ei yhteensopiva)",
    "The following apps have been disabled: %s" : "Seuraavat sovellukset on poistettu käytöstä: %s",
    "Already up to date" : "Kaikki on jo ajan tasalla",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Palvelintasi ei ole määritetty oikein tiedostojen synkronointia varten, koska WebDAV-liitäntä vaikuttaa olevan rikki.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Verkkopalvelintasi ei ole määritelty oikein käsittelemään osoitetta \"{url}\". Lisätietoa löytyy  {linkstart}dokumentaatiosta ↗{linkend}.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Tietokantaasi ei suoriteta \"READ COMMITTED\"-transaktioeristystasolla. Tämä saattaa aiheuttaa ongelmia, kun useita toimintoja suoritetaan rinnakkaisesti.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "PHP \"fileinfo\" moduuli puuttuu. Moduulin käyttöönottaminen on vahvasti suositeltua paremman MIME tyyppien tunnistuksen saavuttamiseksi.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Cron-työtä ei voitu suorittaa komentorivin kautta. Seuraavat tekniset virheet havaittiin:",
    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 on viimeinen julkaiusu, joka tukee PHP:n versiota 7.3. Nextcloud 24 vaatii vähintään PHP:n version 7.4.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-funktio \"set_time_limit\" ei ole käytettävissä. Tämä saattaa johtaa siihen, että skriptien suoritus päättyy ennenaikaisesti ja Nextcloud-asennus rikkoutuu. Funktion käyttäminen on erittäin suositeltavaa.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP-asennuksessasi ei ole FreeType-tukea, ja siitä aiheutuu profiilikuvien sekä asetuskäyttöliittymän rikkoutuminen.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Puuttuva indeksi \"{indexName}\" taulussa \"{tableName}\".",
    "Missing primary key on table \"{tableName}\"." : "Primary key puuttuu taulusta \"{tableName}\".",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Valinnainen sarake \"{columnName}\" puuttuu taulusta \"{tableName}\".",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Palvelimen php-imagick-moduulissa ei ole SVG-tukea. Parempaa yhteensopivuutta varten sen asentaminen on suositeltua.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite on parhaillaan käytössä tietokantaratkaisuna. Suuria asennuksia varten suosittelemme vaihtamaan toiseen tietokantaratkaisuun.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Tämä on suositeltavaa erityisesti silloin, kun työpöytäsovellusta käytetään tiedostojen synkronointiin.",
    "The PHP memory limit is below the recommended value of 512MB." : "PHP:n muistiraja on asetettu alle suositellun 512 megatavun arvon.",
    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "Palvelimen väliaikaistiedostojen hakemiston polku viittaa olemattomaan tai kirjoitussuojattuun hakemistoon.",
    "Error occurred while checking server setup" : "Virhe palvelimen määrityksiä tarkistaessa",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Lue lisätietoja {linkstart}dokumentaatiosta ↗{linkend}.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP-header \"{header}\" ei ole määritetty vastaamaan arvoa \"{expected}\". Kyseessä on mahdollinen tietoturvaan tai -suojaan liittyvä riski, joten on suositeltavaa muuttaa asetuksen arvoa.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP-header \"{header}\" ei ole määritetty vastaamaan arvoa \"{expected}\". Jotkin toiminnot eivät vättämättä toimi oikein, joten on suositeltavaa muuttaa asetuksen arvoa.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Sivua käytetään turvattoman HTTP:n kautta. Palvelimen määrittäminen käyttämään HTTPS-protokollaa on vahvasti suositeltua, kuten kuvattu {linkstart}turvallisuusvinkeissä ↗{linkend}.",
    "unknown text" : "tuntematon teksti",
    "Hello world!" : "Hei maailma!",
    "sunny" : "aurinkoinen",
    "Hello {name}, the weather is {weather}" : "Hei {name}, sää on {weather}",
    "Hello {name}" : "Hei {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Nämä ovat hakutulokset<script>alert(1)</script></strong>",
    "new" : "uusi",
    "_download %n file_::_download %n files_" : ["lataa %n tiedosto","lataa %n tiedostoa"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Päivitys on meneillään. Poistuminen tältä sivulta saattaa keskeyttää toimenpiteen joissain käyttöympäristöissä.",
    "Update to {version}" : "Päivitä versioon {version}",
    "An error occurred." : "Tapahtui virhe.",
    "Please reload the page." : "Päivitä sivu.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Päivitys epäonnistui. Katso lisätietoja tähän ongelmaan liittyen <a href=\"{url}\">keskustelupalstan viestistä</a>.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Päivitys ei onnistunut. Raportoisitko tämän ongelman <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-yhteisölle</a>.",
    "Continue to {productName}" : "Jatka {productName}iin",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Päivitys onnistui. Ohjataan {productName}iin %n sekunnin kuluttua.","Päivitys onnistui. Ohjataan {productName}iin %n sekunnin kuluttua."],
    "More apps" : "Lisää sovelluksia",
    "Currently open" : "Parhaillaan avoinna",
    "_{count} notification_::_{count} notifications_" : ["{count} ilmoitus","{count} ilmoitusta"],
    "Log in" : "Kirjaudu sisään",
    "Logging in …" : "Kirjaudutaan sisään...",
    "Server side authentication failed!" : "Palvelimen puoleinen tunnistautuminen epäonnistui!",
    "Please contact your administrator." : "Ota yhteys ylläpitäjään.",
    "An internal error occurred." : "Tapahtui sisäinen virhe.",
    "Please try again or contact your administrator." : "Yritä uudestaan tai ota yhteys ylläpitäjään.",
    "Log in to {productName}" : "Kirjaudu palveluun {productName}",
    "Account name or email" : "Tilin nimi tai sähköpostiosoite",
    "Password" : "Salasana",
    "Wrong username or password." : "Väärä käyttäjätunnus tai salasana.",
    "User disabled" : "Käyttäjä poistettu käytöstä",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Useita virheellisiä kirjautumisyrityksiä havaittiin IP-osoitteestasi. Siksi seuraava yritys sallitaan vasta 30 sekunnin päästä.",
    "Username or email" : "Käyttäjätunnus tai sähköpostiosoite",
    "Your account is not setup for passwordless login." : "Käyttäjääsi ei ole kytketty käyttämään salasanatonta kirjautumista.",
    "Browser not supported" : "Selain ei ole tuettu",
    "Passwordless authentication is not supported in your browser." : "Selaimesi ei tue tunnistautumista ilman salasanaa.",
    "Your connection is not secure" : "Yhteytesi ei ole turvallinen",
    "Passwordless authentication is only available over a secure connection." : "Tunnistautuminen ilman salasanaa on mahdollista vain salattua yhteyttä käyttäessä.",
    "Reset password" : "Palauta salasana",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Salasanan nollausviesti on lähetetty käyttäjätilin sähköpostiin. Jos et vastaanota sähköpostia, tarkista roskapostikansio tai pyydä apua järjestelmävalvojaltasi.",
    "If it is not there ask your local administrator." : "Jos se ei ole siellä, niin pyydä järjestelmänvalvojaltasi.",
    "Couldn't send reset email. Please contact your administrator." : "Palautussähköpostin lähettäminen ei onnistunut. Ota yhteys ylläpitäjään.",
    "Password cannot be changed. Please contact your administrator." : "Salasanaa ei voi vaihtaa. Ole yhteydessä ylläpitäjään.",
    "Back to login" : "Palaa kirjautumiseen",
    "New password" : "Uusi salasana",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Tiedostosi on salattu. Niitä ei ole mahdollista palauttaa kun salasanasi on palautettu. Jos et ole varma mitä tehdä, ota yhteyttä ylläpitäjään ennen kuin jatkat. Oletko varma, että haluat jatkaa?",
    "I know what I'm doing" : "Tiedän mitä teen",
    "Resetting password" : "Salasanan palauttaminen",
    "Recommended apps" : "Suositellut sovellukset",
    "Loading apps …" : "Ladataan sovelluksia…",
    "Could not fetch list of apps from the App Store." : "Sovelluskaupasta ei voitu noutaa listaa sovelluksista.",
    "Installing apps …" : "Asennetaan sovelluksia…",
    "App download or installation failed" : "Sovelluksen lataus tai asennus epäonnistui",
    "Cannot install this app because it is not compatible" : "Tätä sovellusta ei voi asentaa, koska se ei ole yhteensopiva",
    "Cannot install this app" : "Tätä sovellusta ei voi asentaa",
    "Skip" : "Ohita",
    "Install recommended apps" : "Asenna suositellut sovellukset",
    "Schedule work & meetings, synced with all your devices." : "Aikatauluta työsi ja tapaamisesi synkronoidusti kaikkien laitteitesi välillä.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Pidä työkaverisi ja kaverisi samassa paikassa vuotamatta heidän yksityisiä tietojaan.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Yksinkertainen sähköpostisovellus, joka toimii yhdessä Tiedostojen, Kontaktien ja Kalenterin kanssa.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Keskustelu, videopuhelut, näytön jako, verkkotapaamiset ja web-konferenssit - selaimessasi ja puhelinsovelluksilla.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Asiakirjat, laskentataulukot ja esitykset yhteistyönä, taustavoimana Collabora Online.",
    "Forgot password?" : "Unohditko salasanasi?",
    "Log in with a device" : "Kirjaudu laitteella",
    "Back" : "Takaisin",
    "Login form is disabled." : "Kirjautumislomake on poistettu käytöstä.",
    "Edit Profile" : "Muokkaa profiilia",
    "The headline and about sections will show up here" : "Otsikko ja listätieto-osiot näkyvät tässä",
    "You have not added any info yet" : "Et ole lisännyt tietoja vielä",
    "{user} has not added any info yet" : "{user} ei ole lisännyt tietoja vielä",
    "Search starts once you start typing" : "Haku käynnistyy kun alat kirjoittamaan",
    "Reset search" : "Tyhjennä haku",
    "Start search" : "Aloita haku",
    "Search for {name} only" : "Etsi vain {name}",
    "No results for {query}" : "Ei tuloksia haulle {query}",
    "Press enter to start searching" : "Paina enter aloittaaksesi haun",
    "Start typing to search" : "Aloita kirjoittaminen hakeaksesi",
    "Loading more results …" : "Ladataan lisää tuloksia…",
    "Load more results" : "Lataa lisää tuloksia",
    "Search" : "Etsi",
    "An error occurred while searching for {type}" : "Haettaessa tyyppiä {type} tapahtui virhe.",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Kirjoita vähintään {minSearchLength} merkki etsiäksesi","Kirjoita vähintään {minSearchLength} merkkiä etsiäksesi"],
    "This browser is not supported" : "Tämä selain ei ole tuettu",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Selaimesi ei ole tuettu. Päivitä uudempaan versioon tai muuhun tuettuun selaimeen.",
    "Continue with this unsupported browser" : "Jatka tällä tuen ulkopuolella olevalla selaimella",
    "Supported versions" : "Tuetut versiot",
    "{name} version {version} and above" : "Selaimen {name} versio {version} ja uudempi",
    "Search {types} …" : "Etsi {types}…",
    "Settings" : "Asetukset",
    "Could not load your contacts" : "Yhteystietojasi ei voitu ladata",
    "Search contacts …" : "Etsi yhteystietoja…",
    "No contacts found" : "Yhteystietoja ei löytynyt",
    "Show all contacts …" : "Näytä kaikki yhteystiedot…",
    "Install the Contacts app" : "Asenna Yhteystiedot-sovellus",
    "Loading your contacts …" : "Ladataan yhteystietojasi…",
    "Looking for {term} …" : "Etsii {term}…",
    "No" : "Ei",
    "Yes" : "Kyllä",
    "No files in here" : "Täällä ei ole tiedostoja",
    "New folder" : "Uusi kansio",
    "No more subfolders in here" : "Täällä ei ole enempää alikansioita",
    "Name" : "Nimi",
    "Size" : "Koko",
    "Modified" : "Muokattu",
    "\"{name}\" is an invalid file name." : "\"{name}\" on virheellinen tiedostonimi.",
    "File name cannot be empty." : "Tiedoston nimi ei voi olla tyhjä.",
    "\"/\" is not allowed inside a file name." : "\"/\" ei ole sallittu merkki tiedostonimessä.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" ei ole hyväksytty tiedostotyyppi",
    "{newName} already exists" : "{newName} on jo olemassa",
    "Choose" : "Valitse",
    "Copy" : "Kopioi",
    "Move" : "Siirrä",
    "Error loading file picker template: {error}" : "Virhe ladatessa tiedostopohjia: {error}",
    "OK" : "OK",
    "Error loading message template: {error}" : "Virhe ladatessa viestipohjaa: {error}",
    "read-only" : "vain luku",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} tiedoston ristiriita","{count} tiedoston ristiriita"],
    "One file conflict" : "Yhden tiedoston ristiriita",
    "New Files" : "Uudet tiedostot",
    "Already existing files" : "Jo olemassa olevat tiedostot",
    "Which files do you want to keep?" : "Mitkä tiedostot haluat säilyttää?",
    "If you select both versions, the copied file will have a number added to its name." : "Jos valitset kummatkin versiot, kopioidun tiedoston nimeen lisätään numero.",
    "Cancel" : "Peruuta",
    "Continue" : "Jatka",
    "(all selected)" : "(kaikki valittu)",
    "({count} selected)" : "({count} valittu)",
    "Error loading file exists template" : "Virhe ladatessa mallipohjaa",
    "Show list view" : "Näytä listanäkymä",
    "Show grid view" : "Näytä ruudukkonäkymä",
    "Pending" : "Odottaa",
    "Copy to {folder}" : "Kopioi kansioon {folder}",
    "Move to {folder}" : "Siirrä kansioon {folder}",
    "Saving …" : "Tallennetaan…",
    "Authentication required" : "Tunnistautuminen vaaditaan",
    "This action requires you to confirm your password" : "Toiminto vaatii vahvistamista salasanallasi",
    "Confirm" : "Vahvista",
    "Failed to authenticate, try again" : "Varmennus epäonnistui, yritä uudelleen",
    "seconds ago" : "sekunteja sitten",
    "Connection to server lost" : "Yhteys palvelimelle katkesi",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua","Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua"],
    "Add to a project" : "Lisää projektiin",
    "Show details" : "Näytä tiedot",
    "Hide details" : "Piilota tiedot",
    "Rename project" : "Nimeä projekti uudelleen",
    "Failed to rename the project" : "Projektin nimeäminen uudelleen epäonnistui",
    "Failed to create a project" : "Projektin luominen epäonnistui",
    "Failed to add the item to the project" : "Kohteen lisääminen projektiin epäonnistui",
    "Connect items to a project to make them easier to find" : "Yhdistä kohteita projektiin tehdäksesi niiden löytämisestä helpompaa",
    "Type to search for existing projects" : "Kirjoita etsiäksesi olemassa olevia projekteja",
    "New in" : "Uutta versiossa",
    "View changelog" : "Katso muutosloki",
    "Very weak password" : "Erittäin heikko salasana",
    "Weak password" : "Heikko salasana",
    "So-so password" : "Kohtalainen salasana",
    "Good password" : "Hyvä salasana",
    "Strong password" : "Vahva salasana",
    "No action available" : "Toimintoa ei saatavilla",
    "Error fetching contact actions" : "Virhe yhteystiedon toimintojen haussa",
    "Non-existing tag #{tag}" : "Ei olemassa oleva tunniste #{tag}",
    "Restricted" : "Rajoitettu",
    "Invisible" : "Näkymätön",
    "Delete" : "Poista",
    "Rename" : "Nimeä uudelleen",
    "Collaborative tags" : "Yhteistyölliset tunnisteet",
    "No tags found" : "Tunnisteita ei löytynyt",
    "Personal" : "Henkilökohtainen",
    "Users" : "Käyttäjät",
    "Apps" : "Sovellukset",
    "Admin" : "Ylläpito",
    "Help" : "Ohje",
    "Access forbidden" : "Pääsy estetty",
    "Profile not found" : "Profiilia ei löytynyt",
    "The profile does not exist." : "Profiilia ei ole olemassa",
    "Back to %s" : "Takaisin kohtaan %s",
    "Page not found" : "Sivua ei löytynyt",
    "The page could not be found on the server." : "Sivua ei löytynyt palvelimelta.",
    "Too many requests" : "Liian monta pyyntöä",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Verkostasi tehtiin liian monta pyyntöä. Yritä myöhemmin uudelleen tai ole yhteydessä ylläpitäjään, jos tämä on mielestäsi virhe.",
    "Error" : "Virhe",
    "Previous" : "Edellinen",
    "Internal Server Error" : "Sisäinen palvelinvirhe",
    "The server was unable to complete your request." : "Palvelin ei kyennyt käsittelemään pyyntöäsi.",
    "If this happens again, please send the technical details below to the server administrator." : "Jos tämä tapahtuu uudelleen, lähetä alla olevat tekniset tiedot palvelimen ylläpitäjälle.",
    "More details can be found in the server log." : "Lisätietoja on palvelimen lokitiedostossa.",
    "Technical details" : "Tekniset tiedot",
    "Remote Address: %s" : "Etäosoite: %s",
    "Request ID: %s" : "Pyynnön tunniste: %s",
    "Type: %s" : "Tyyppi: %s",
    "Code: %s" : "Koodi: %s",
    "Message: %s" : "Viesti: %s",
    "File: %s" : "Tiedosto: %s",
    "Line: %s" : "Rivi: %s",
    "Trace" : "Jälki",
    "Security warning" : "Turvallisuusvaroitus",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Datakansiosi ja tiedostosi ovat mitä luultavimmin muiden nähtävissä Internetistä, koska .htaccess-tiedosto ei toimi.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Lisätietoja palvelimen kunnollisista asetuksista on <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">ohjeissa</a>.",
    "Create an <strong>admin account</strong>" : "Luo <strong>ylläpitäjän tunnus</strong>",
    "Username" : "Käyttäjätunnus",
    "Show password" : "Näytä salasana",
    "Toggle password visibility" : "Näytä/piilota salasana",
    "Storage & database" : "Tallennus ja tietokanta",
    "Data folder" : "Datakansio",
    "Configure the database" : "Määritä tietokanta",
    "Only %s is available." : "Vain %s on käytettävissä.",
    "Install and activate additional PHP modules to choose other database types." : "Asenna ja aktivoi erillisiä PHP-moduuleja valitaksesi muita tietokantatyyppejä.",
    "For more details check out the documentation." : "Lue lisätiedot ohjeista.",
    "Database user" : "Tietokannan käyttäjä",
    "Database password" : "Tietokannan salasana",
    "Database name" : "Tietokannan nimi",
    "Database tablespace" : "Tietokannan taulukkotila",
    "Database host" : "Tietokantapalvelin",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Määritä portin numero tietokantapalvelimen yhteydessä (esim. localhost:5432).",
    "Performance warning" : "Suorituskykyvaroitus",
    "You chose SQLite as database." : "Valitsit SQLiten tietokannaksi.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite tulisi ottaa käyttöön vain minimaalisissa kehitysympäristöissä. Tuotantokäyttöön suosittelemme toista tietokantaratkaisua.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jos käytät asiakasohjelmia tiedostojen synkronointiin, SQLiten käyttöä ei suositella.",
    "Install" : "Asenna",
    "Installing …" : "Asennetaan …",
    "Need help?" : "Tarvitsetko apua?",
    "See the documentation" : "Tutustu ohjeisiin",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Vaikuttaa siltä, että yrität Nextcloudin uudelleenasennusta. Tiedosto CAN_INSTALL puuttuu asetuskansiosta. Ole hyvä ja luo tiedosto CAN_INSTALL asetuskansioon jatkaaksesi.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Tiedostoa CAN_INSTALL ei voitu poistaa asetuskansiosta. Poista tiedosto manuaalisesti.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Tämä sovellus vaatii toimiakseen JavaScript-tuen. {linkstart}Ota JavaScript käyttöön{linkend} ja päivitä sivu.",
    "Skip to main content" : "Siirry pääsisältöön",
    "Skip to navigation of app" : "Hyppää sovelluksen navigointiin.",
    "Get your own free account" : "Hanki ilmainen tili itsellesi",
    "%s's homepage" : "Käyttäjän %s kotisivu",
    "Contacts" : "Yhteystiedot",
    "Contacts menu" : "Yhteystietovalikko",
    "Open settings menu" : "Avaa asetukset",
    "Confirm your password" : "Vahvista salasanasi",
    "Connect to your account" : "Yhdistä tiliisi",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jos et ole asentamassa uutta laitetta tai sovellusta, joku yrittää huijata sinut antamaan käyttöoikeudet tietoihisi. Tässä tapauksessa älä jatka, ota yhteys järjestelmänvalvojaan.",
    "App token" : "Sovellusvaltuutus",
    "Grant access" : "Myönnä pääsy",
    "Alternative log in using app token" : "Vaihtoehtoinen kirjautuminen käyttäen sovelluspolettia",
    "Account access" : "Tilin käyttö",
    "Currently logged in as %1$s (%2$s)." : "Kirjautuneena käyttäjänä %1$s (%2$s).",
    "Account connected" : "Tili yhdistetty",
    "Your client should now be connected!" : "Päätteesi pitäisi olla yhdistetty!",
    "You can close this window." : "Voit sulkea tämän ikkunan.",
    "This share is password-protected" : "Jako on salasanasuojattu",
    "The password is wrong or expired. Please try again or request a new one." : "Salasana on väärä tai vanhentunut. Yritä uudelleen tai pyydä uusi salasana.",
    "Please type in your email address to request a temporary password" : "Kirjoita sähköpostiosoitteesi pyytääksesi väliaikaista salasanaa",
    "Email address" : "Sähköpostiosoite",
    "Password sent!" : "Salasana lähetetty!",
    "You are not authorized to request a password for this share" : "Sinulla ei ole valtuutta pyytää salasanaa tähän jakoon",
    "Go to %s" : "Siirry %s§",
    "Two-factor authentication" : "Kaksivaiheinen tunnistautuminen",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Tilisi tietoturvatasoa on korotettu. Käytä kaksivaiheista tunnistautumista:",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Kaksivaiheinen tunnistautuminen on pakotettu, mutta sitä ei ole määritelty tilillesi. Ole yhteydessä ylläpitoon saadaksesi apua.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Kaksivaiheinen tunnistautuminen on pakotettu, mutta sitä ei ole määritelty tilillesi. Jatka asettaaksesi kaksivaiheisen tunnistautumisen.",
    "Set up two-factor authentication" : "Määritä kaksivaiheinen tunnistautuminen",
    "Use backup code" : "Käytä varakoodia",
    "Cancel login" : "Peru kirjautuminen",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Parannettu suojaus on käytössä käyttäjätilissäsi. Valitse asennettava tarjoaja:",
    "Error while validating your second factor" : "Tunnistuksen toisen vaiheen tarkistus epäonnistui",
    "Access through untrusted domain" : "Käyttö epäluotettavasta toimialueesta",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Ota yhteys ylläpitoon, tai jos olet tämän palvelun ylläpitäjä, määritä \"trusted_domains\"-asetus config/config.php-tiedostossa. Esimerkkimääritys on tiedostossa config/config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Lisätietoa tämän määrittämisestä löydät %1$sdokumentaatiosta%2$s.",
    "App update required" : "Sovelluksen päivittäminen vaaditaan",
    "%1$s will be updated to version %2$s" : "%1$s päivitetään versioon %2$s",
    "The following apps will be updated:" : "Seuraavat sovellukset päivitetään:",
    "These incompatible apps will be disabled:" : "Nämä yhteensopimattomat sovellukset poistetaan käytöstä:",
    "The theme %s has been disabled." : "Teema %s on poistettu käytöstä.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Varmista ennen jatkamista, että tietokanta, asetuskansio ja datakansio on varmuuskopioitu.",
    "Start update" : "Käynnistä päivitys",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Välttääksesi aikakatkaisuja suurikokoisten asennusten kanssa, voit suorittaa vaihtoehtoisesti seuraavan komennon asennushakemistossa:",
    "Detailed logs" : "Yksityiskohtainen loki",
    "Update needed" : "Päivitys vaaditaan",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Käytä komentorivipäivitintä, koska käyttäjiä on yli 50.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Jos tarvitset apua, katso <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">ohjeista</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Tiedän että jos jatkan päivittämistä web-liittymän kautta, saatan menettää kaikki tiedostot, mikäli päivitys epäonnistuu. Onneksi olen tehnyt varmuuskopion ja osaan sen myös palauttaa tarvittaessa.",
    "Upgrade via web on my own risk" : "Internetin kautta päivittäminen omalla vastuulla",
    "Maintenance mode" : "Huoltotila",
    "This %s instance is currently in maintenance mode, which may take a while." : "Tämä %s-instanssi on parhaillaan huoltotilassa, huollossa saattaa kestää hetki.",
    "This page will refresh itself when the instance is available again." : "Tämä sivu päivittyy itsestään, kun instanssi on jälleen käytettävissä.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Ota yhteys järjestelmän ylläpitäjään, jos tämä viesti ilmenee uudelleen tai odottamatta.",
    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Syötä tilausavaimesi lisätäksesi käyttäjärajaa. Lisätietoja Nextcloud Enterprisestä saat nettisivuiltamme.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Tarkistetaan taulua %s",
    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 on viimeinen julkaisu, joka tukee PHP:n versiota 7.2. Nextcloud 21 vaatii vähintään version 7.3 PHP:sta.",
    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "PHP OPCache moduuli ei ole ladattuna. {linkstart}Paremman suorituskyvyn saavuttamiseksi↗{linkend}  suosittelemme sen lataamista PHP asennukseesi.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "Siirtyäksesi toiseen tietokantaan, käytä komentorivityökalua: 'occ db:convert-type', tai lue {linkstart}dokumentaatio ↗{linkend}.",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Data-hakemisto ja tiedostot ovat luultavasti käytettävissä suoraan Internetistä. .htaccess-tiedosto ei toimi oikein. Suosittelemme määrittämään HTTP-palvelimen asetukset siten, ettei data-hakemisto ole suoraan käytettävissä Internetistä tai siirtämään data-hakemiston HTTP-palvelimen juurihakemiston ulkopuolelle.",
    "Collaboratively edit office documents." : "Muokkaa toimistodokumentteja yhteistyössä.",
    "Local document editing back-end used by the Collabora Online app." : "Collabora Online-sovelluksen käyttämä taustasovellus paikalliseen dokumenttien muokkaamiseen.",
    "restricted" : "rajoitettu",
    "invisible" : "näkymätön",
    "File not found" : "Tiedostoa ei löytynyt",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Tätä asiakirjaa ei löytynyt palvelimelta. Kenties jako on poistettu tai se oli asetettu vanhenemaan.",
    "More" : "Lisää",
    "More apps menu" : "Lisäsovellusvalikko",
    "Settings menu" : "Asetusvalikko",
    "The password is wrong. Try again." : "Salasana on väärin. Yritä uudelleen.",
    "Setup two-factor authentication" : "Määritä kaksivaiheinen tunnistautuminen",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Tätä yhteisöjulkaisua Nextcloudista ei tueta, ja pikailmoitukset eivät ole saatavilla.",
    "You haven't added any info yet" : "Et ole lisännyt tietoja vielä",
    "{user} hasn't added any info yet" : "{user} ei ole lisännyt tietoja vielä"
},
"nplurals=2; plural=(n != 1);");
